<?php

namespace Litecms\Usernotice\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Usernotice\Http\Requests\UsernoticeRequest;
use Litecms\Usernotice\Interfaces\UsernoticeRepositoryInterface;
use Litecms\Usernotice\Models\Usernotice;

/**
 * Resource controller class for usernotice.
 */
class UsernoticeResourceController extends BaseController
{

    /**
     * Initialize usernotice resource controller.
     *
     * @param type UsernoticeRepositoryInterface $usernotice
     *
     * @return null
     */
    public function __construct(UsernoticeRepositoryInterface $usernotice)
    {
        parent::__construct();
        $this->repository = $usernotice;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Usernotice\Repositories\Criteria\UsernoticeResourceCriteria::class);
    }

    /**
     * Display a list of usernotice.
     *
     * @return Response
     */
    public function index(UsernoticeRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Usernotice\Repositories\Presenter\UsernoticePresenter::class)
                ->$function();
        }

        $usernotices = $this->repository->paginate();

        return $this->response->title(trans('usernotice::usernotice.names'))
            ->view('usernotice::usernotice.index', true)
            ->data(compact('usernotices'))
            ->output();
    }

    /**
     * Display usernotice.
     *
     * @param Request $request
     * @param Model   $usernotice
     *
     * @return Response
     */
    public function show(UsernoticeRequest $request, Usernotice $usernotice)
    {

        if ($usernotice->exists) {
            $view = 'usernotice::usernotice.show';
        } else {
            $view = 'usernotice::usernotice.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('usernotice::usernotice.name'))
            ->data(compact('usernotice'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new usernotice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(UsernoticeRequest $request)
    {

        $usernotice = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('usernotice::usernotice.name')) 
            ->view('usernotice::usernotice.create', true) 
            ->data(compact('usernotice'))
            ->output();
    }

    /**
     * Create new usernotice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(UsernoticeRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $usernotice                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('usernotice::usernotice.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('usernotice/usernotice/' . $usernotice->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/usernotice/usernotice'))
                ->redirect();
        }

    }

    /**
     * Show usernotice for editing.
     *
     * @param Request $request
     * @param Model   $usernotice
     *
     * @return Response
     */
    public function edit(UsernoticeRequest $request, Usernotice $usernotice)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('usernotice::usernotice.name'))
            ->view('usernotice::usernotice.edit', true)
            ->data(compact('usernotice'))
            ->output();
    }

    /**
     * Update the usernotice.
     *
     * @param Request $request
     * @param Model   $usernotice
     *
     * @return Response
     */
    public function update(UsernoticeRequest $request, Usernotice $usernotice)
    {
        try {
            $attributes = $request->all();

            $usernotice->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('usernotice::usernotice.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('usernotice/usernotice/' . $usernotice->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('usernotice/usernotice/' . $usernotice->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the usernotice.
     *
     * @param Model   $usernotice
     *
     * @return Response
     */
    public function destroy(UsernoticeRequest $request, Usernotice $usernotice)
    {
        try {

            $usernotice->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('usernotice::usernotice.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('usernotice/usernotice/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('usernotice/usernotice/' . $usernotice->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple usernotice.
     *
     * @param Model   $usernotice
     *
     * @return Response
     */
    public function delete(UsernoticeRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('usernotice::usernotice.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('usernotice/usernotice'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/usernotice/usernotice'))
                ->redirect();
        }

    }

    /**
     * Restore deleted usernotices.
     *
     * @param Model   $usernotice
     *
     * @return Response
     */
    public function restore(UsernoticeRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('usernotice::usernotice.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/usernotice/usernotice'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/usernotice/usernotice/'))
                ->redirect();
        }

    }

}
